==> rs485-5.1.1.tar.bz2: rs485-5.1.1/kernel/pci/pci.c <==
#include	<linux/pci.h>
#include	<linux/errno.h>

#include	"mcua.h"
#include	"rs485.h"
#include	"moxa132.h"

extern	int io1, io2;
extern	int irq1, irq2;

#ifndef KERN_2_6
int _find_PCImoxa(void)	{	//   MOXA CP132
	int res;
	u32 curr, msk;
	char bt;
	unsigned char bus,func;
	 
	res = pcibios_find_device( VENDOR_CARD, ID_CARD, 0, 
							&bus, &func);
	if(res != 0) {
		return(res);	/*    */
	}
	/*       
	 *    /  
	 */
	pcibios_read_config_dword(bus, func,
					PCI_BASE_ADDRESS_2, &curr);
	cli();
	pcibios_write_config_dword(bus, func,
					PCI_BASE_ADDRESS_2, ~0);	
	pcibios_read_config_dword(bus, func,
					PCI_BASE_ADDRESS_2, &msk);
	pcibios_write_config_dword(bus, func,
					PCI_BASE_ADDRESS_2, curr);	
	sti();
	if(msk & PCI_BASE_ADDRESS_SPACE){
		msk &= PCI_BASE_ADDRESS_IO_MASK;
	} else {
		printk("3\n");
		return(-EIO); /*    */
	}
	
	pcibios_read_config_byte(bus, func,
					PCI_REVISION_ID, &bt);
	
	pcibios_read_config_byte(bus, func,
					PCI_INTERRUPT_LINE, &bt);
	irq1 = bt;
	irq2 = irq1;
	io1 = (int) curr-1;
	io2 = io1 + 8;
		printk("io1=%x io2=%x\n",io1,io2);
	pcibios_write_config_byte(bus, func,
						PCI_CACHE_LINE_SIZE, 8);
	return (0);
}

#else

int _find_PCImoxa(void)	{	//   MOXA CP132
	u32 curr, msk;
	char bt;

	struct pci_dev *dev = pci_get_device(VENDOR_CARD, ID_CARD,NULL);

	if(dev) {

//	     
//	   /  
                          
		pci_read_config_dword(dev, PCI_BASE_ADDRESS_2, &curr);
		pci_write_config_dword(dev, PCI_BASE_ADDRESS_2, ~0);
		pci_read_config_dword(dev, PCI_BASE_ADDRESS_2, &msk);
		pci_write_config_dword(dev, PCI_BASE_ADDRESS_2, curr);

		if(msk & PCI_BASE_ADDRESS_SPACE) {
			msk &= PCI_BASE_ADDRESS_IO_MASK;
		} else {
			pci_dev_put(dev);
			return(-EIO);
		}

		pci_read_config_byte(dev, PCI_REVISION_ID, &bt);
		pci_read_config_byte(dev, PCI_INTERRUPT_LINE, &bt);
		irq1 = bt;
		irq2 = irq1;
		io1 = (int) curr-1;
		io2 = io1 + 8;
		pci_write_config_byte(dev, PCI_CACHE_LINE_SIZE, 8);
		
		pci_dev_put(dev);

	} else {
		return(-ENODEV); 	// No such device
	}
	return(0);
}
#endif

==> rs485-5.1.3.tar.bz2: rs485-5.1.3/kernel/pci/pci.c <==
#include	<linux/pci.h>
#include	<linux/errno.h>

#include	"mcua.h"
#include	"rs485.h"
#include	"moxa132.h"

extern	int io1, io2;
extern	int irq1, irq2;

#ifndef KERN_2_6
int _find_PCImoxa(void)	{
	int res;
	u32 curr, msk;
	char bt;
	unsigned char bus,func;
	 
	res = pcibios_find_device( VENDOR_CARD, ID_CARD, 0, 
							&bus, &func);
	if(res != 0) {
		return(res); // not found
	}
	pcibios_read_config_dword(bus, func,
					PCI_BASE_ADDRESS_2, &curr);
	cli();
	pcibios_write_config_dword(bus, func,
					PCI_BASE_ADDRESS_2, ~0);	
	pcibios_read_config_dword(bus, func,
					PCI_BASE_ADDRESS_2, &msk);
	pcibios_write_config_dword(bus, func,
					PCI_BASE_ADDRESS_2, curr);	
	sti();
	if(msk & PCI_BASE_ADDRESS_SPACE){
		msk &= PCI_BASE_ADDRESS_IO_MASK;
	} else {
		printk("3\n");
		return(-EIO);
	}
	
	pcibios_read_config_byte(bus, func,
					PCI_REVISION_ID, &bt);
	
	pcibios_read_config_byte(bus, func,
					PCI_INTERRUPT_LINE, &bt);
	irq1 = bt;
	irq2 = irq1;
	io1 = (int) curr-1;
	io2 = io1 + 8;
		printk("io1=%x io2=%x\n",io1,io2);
	pcibios_write_config_byte(bus, func,
						PCI_CACHE_LINE_SIZE, 8);
	return (0);
}

#else

int _find_PCImoxa(void)	{
	u32 curr, msk;
	char bt;

	struct pci_dev *dev = pci_get_device(VENDOR_CARD, ID_CARD,NULL);

	if(dev) {

		pci_read_config_dword(dev, PCI_BASE_ADDRESS_2, &curr);
		pci_write_config_dword(dev, PCI_BASE_ADDRESS_2, ~0);
		pci_read_config_dword(dev, PCI_BASE_ADDRESS_2, &msk);
		pci_write_config_dword(dev, PCI_BASE_ADDRESS_2, curr);

		if(msk & PCI_BASE_ADDRESS_SPACE) {
			msk &= PCI_BASE_ADDRESS_IO_MASK;
		} else {
			pci_dev_put(dev);
			return(-EIO);
		}

		pci_read_config_byte(dev, PCI_REVISION_ID, &bt);
		pci_read_config_byte(dev, PCI_INTERRUPT_LINE, &bt);
		irq1 = bt;
		irq2 = irq1;
		io1 = (int) curr-1;
		io2 = io1 + 8;
		pci_write_config_byte(dev, PCI_CACHE_LINE_SIZE, 8);
		
		pci_dev_put(dev);

	} else {
		return(-ENODEV); 	// No such device
	}
	return(0);
}
#endif
